@@ -18,6 +18,8 @@ from copy import deepcopy
 import aiohttp
 import taskcluster
 import taskcluster.exceptions
+from taskcluster.exceptions import TaskclusterFailure
+
 from scriptworker.constants import get_reversed_statuses
 from scriptworker.exceptions import ScriptWorkerTaskException, WorkerShutdownDuringTask
 from scriptworker.github import (
@@ -29,7 +31,7 @@ from scriptworker.github import (
 )
 from scriptworker.log import get_log_filehandle, pipe_to_log
 from scriptworker.task_process import TaskProcess
-from scriptworker.utils import get_parts_of_url_path
+from scriptworker.utils import get_parts_of_url_path, retry_async
 
 log = logging.getLogger(__name__)
 
@@ -51,6 +53,39 @@ def worst_level(level1, level2):
     return level1 if level1 > level2 else level2
 
 
+# get_task_definition {{{1
+async def get_task_definition(queue, task_id, exception=TaskclusterFailure):
+    """Get the task definition from the queue.
+
+    Detect whether the task definition is empty, per bug 1618731.
+
+    Args:
+        queue (taskcluster.aio.Queue): the taskcluster Queue object
+        task_id (str): the taskId of the task
+        exception (Exception, optional): the exception to raise if unsuccessful.
+            Defaults to ``TaskclusterFailure``.
+
+    """
+    task_defn = await queue.task(task_id)
+    if "payload" not in task_defn:
+        raise exception("Task definition for {} is empty!\n {}".format(task_id, task_defn))
+    return task_defn
+
+
+async def retry_get_task_definition(queue, task_id, exception=TaskclusterFailure, **kwargs):
+    """Retry ``get_task_definition``.
+
+    Args:
+        queue (taskcluster.aio.Queue): the taskcluster Queue object
+        task_id (str): the taskId of the task
+        exception (Exception, optional): the exception to raise if unsuccessful.
+            Defaults to ``TaskclusterFailure``.
+
+    """
+    kwargs.setdefault("retry_exceptions", tuple(set([TaskclusterFailure, exception])))
+    return await retry_async(get_task_definition, args=(queue, task_id), kwargs={"exception": exception}, **kwargs)
+
+
 # get_task_id {{{1
 def get_task_id(claim_task):
     """Given a claim_task json dict, return the taskId.
@@ -609,7 +644,7 @@ async def run_task(context, to_cancellable_process):
     if stopped_due_to_worker_shutdown:
         raise WorkerShutdownDuringTask
 
-    return 1 if exitcode != 0 else 0
+    return exitcode
 
 
 # reclaim_task {{{1
@@ -712,5 +747,5 @@ async def claim_work(context):
     }
     try:
         return await context.queue.claimWork(context.config["provisioner_id"], context.config["worker_type"], payload)
-    except (taskcluster.exceptions.TaskclusterFailure, aiohttp.ClientError) as exc:
+    except (taskcluster.exceptions.TaskclusterFailure, aiohttp.ClientError, asyncio.TimeoutError) as exc:
         log.warning("{} {}".format(exc.__class__, exc))
