@@ -16,16 +16,24 @@ import re
 import shutil
 import time
 from copy import deepcopy
-from typing import IO, Any, Awaitable, Callable, Dict, Match, Optional, Sequence, Tuple, Type, Union, cast, overload
+from typing import IO, TYPE_CHECKING, Any, Awaitable, Callable, Dict, Match, Optional, Sequence, Tuple, Type, Union, cast, overload
 from urllib.parse import unquote, urlparse
 
 import aiohttp
 import arrow
 import async_timeout
 import yaml
-from scriptworker.exceptions import Download404, DownloadError, ScriptWorkerException, ScriptWorkerRetryException, ScriptWorkerTaskException
 from taskcluster.client import createTemporaryCredentials
 
+from scriptworker.exceptions import Download404, DownloadError, ScriptWorkerException, ScriptWorkerRetryException, ScriptWorkerTaskException
+
+if TYPE_CHECKING:
+    # Avoid circular import
+    from scriptworker.context import Context
+else:
+    Context = object
+
+
 log = logging.getLogger(__name__)
 
 
@@ -108,7 +116,7 @@ def datestring_to_timestamp(datestring):
         int: the corresponding timestamp.
 
     """
-    return arrow.get(datestring).timestamp
+    return arrow.get(datestring).int_timestamp
 
 
 # to_unicode {{{1
@@ -227,6 +235,7 @@ async def retry_async(
     args: Sequence[Any] = (),
     kwargs: Optional[Dict[str, Any]] = None,
     sleeptime_kwargs: Optional[Dict[str, Any]] = None,
+    log_exceptions: Optional[bool] = False,
 ) -> Any:
     """Retry ``func``, where ``func`` is an awaitable.
 
@@ -257,7 +266,9 @@ async def retry_async(
     while True:
         try:
             return await func(*args, **kwargs)
-        except retry_exceptions:
+        except retry_exceptions as exc:
+            if log_exceptions:
+                log.warning(f"retry_async exception:\n{type(exc)} {exc}")
             attempt += 1
             _check_number_of_attempts(attempt, attempts, func, "retry_async")
             await asyncio.sleep(_define_sleep_time(sleeptime_kwargs, sleeptime_callback, attempt, func, "retry_async"))
@@ -706,7 +717,7 @@ def get_parts_of_url_path(url):
 
 
 # load_json_or_yaml_from_url {{{1
-async def load_json_or_yaml_from_url(context, url, path, overwrite=True, auth=None):
+async def load_json_or_yaml_from_url(context: Context, url: str, path: str, overwrite: bool = True, auth: Optional[str] = None) -> Dict[str, Any]:
     """Retry a json/yaml file download, load it, then return its data.
 
     Args:
@@ -732,7 +743,7 @@ async def load_json_or_yaml_from_url(context, url, path, overwrite=True, auth=No
     if auth:
         kwargs = {"auth": auth}
     if not overwrite or not os.path.exists(path):
-        await retry_async(download_file, args=(context, url, path), kwargs=kwargs, retry_exceptions=(DownloadError, aiohttp.ClientError))
+        await retry_async(download_file, args=(context, url, path), kwargs=kwargs, retry_exceptions=(DownloadError, aiohttp.ClientError, asyncio.TimeoutError))
     return load_json_or_yaml(path, is_path=True, file_type=file_type)
 
 
@@ -880,3 +891,28 @@ def get_single_item_from_sequence(
     if append_sequence_to_error_message:
         error_message = "{}. Given: {}".format(error_message, sequence)
     raise ErrorClass(error_message)
+
+
+# semaphore_wrapper {{{1
+async def semaphore_wrapper(semaphore, coro):
+    """Wrap an async function with semaphores.
+
+    Usage::
+
+        semaphore = asyncio.Semaphore(10)  # max 10 concurrent
+        futures = []
+        futures.append(asyncio.ensure_future(semaphore_wrapper(
+            semaphore, do_something(arg1, arg2, kwarg1='foo')
+        )))
+        await raise_future_exceptions(futures)
+
+    Args:
+        semaphore (asyncio.Semaphore): the semaphore to wrap the action with
+        coro (coroutine): an asyncio coroutine
+
+    Returns:
+        the result of ``action``.
+
+    """
+    async with semaphore:
+        return await coro
